/*
    core.android.js
    v1.0
    create bridge for qq browser
    client environment can only be Android-Ex
    date:2014-08-13
*/

; !function (window, ns, bridge) {

    "use strict";

    var exports = window[ns] = window[ns] || {};

    // 此方法用于创建 qb_channel
    !function () {
        var QbChannel = function (type) {
            this.type = type;
            this.handlers = {};
            this.numHandlers = 0;
            this.onHasSubscribersChange = null;
        };

        QbChannel.prototype.subscribe = function (f) {
            var func = f,
                guid = f.observer_guid;

            if (!guid) {
                // first time any channel has seen this subscriber
                guid = '' + window.qb_channel.nextGuid++;
            }
            func.observer_guid = guid;
            f.observer_guid = guid;

            // Don't add the same handler more than once.
            if (!this.handlers[guid]) {
                this.handlers[guid] = func;
                this.numHandlers++;
                if (this.numHandlers == 1) {
                    this.onHasSubscribersChange && this.onHasSubscribersChange();
                }
            }
        };

        /**
         * Unsubscribes the function with the given guid from the channel.
         */
        QbChannel.prototype.unsubscribe = function (f) {
            var guid = f.observer_guid,
                handler = this.handlers[guid];
            if (handler) {
                delete this.handlers[guid];
                this.numHandlers--;
                if (this.numHandlers === 0) {
                    this.onHasSubscribersChange && this.onHasSubscribersChange();
                }
            }
        };

        /**
         * Calls all functions subscribed to this channel.
         */
        QbChannel.prototype.fire = function (e) {
            if (this.numHandlers) {
                // Copy the values first so that it is safe to modify it from within
                // callbacks.
                var toCall = [];
                for (var item in this.handlers) {
                    toCall.push(this.handlers[item]);
                }
                for (var i = 0; i < toCall.length; ++i) {
                    toCall[i](e);
                }
            }
        };

        window.qb_channel = {
            create: function (type) {
                return window.qb_channel[type] = new QbChannel(type);
            },
            nextGuid: 0
        };
    }();

    // 调用bridge
    if (typeof bridge === 'function') {
        bridge();
    }

    // 创建命名空间
    var createNamespace = function (name) {
        var arr = name.split('.'),
            space = window;
        arr.forEach(function (a) {
            !space[a] && (space[a] = {});
            space = space[a];
        });
        return space;
    };

    //用来对API进行定义
    exports.define = function (name, fn) {
        var index = name.lastIndexOf('.'),
            ns = createNamespace(name.substring(0, index));
        ns[name.substring(index + 1)] = fn;
    };

}(window, 'browser', function () {
    // 大包版直接使用qb_bridge对象
    var qb_bridge = window.qb_bridge;
	// 注：有些Webview中未注入qb_bridge对象，直接使用内核对象
	if (!qb_bridge) {
		return;
	}
	
    qb_bridge.callbackId = Math.floor(Math.random() * 2000000000);
    qb_bridge.callbacks = {};

    qb_bridge.exec = function (success, fail, service, action, args) {
        var callbackId = service + qb_bridge.callbackId++,
            argsJson = args ? JSON.stringify(args) : "";

        if (success || fail) {
            qb_bridge.callbacks[callbackId] = { success: success, fail: fail };
        }

        var ret = qb_bridge.nativeExec(service, action, callbackId, argsJson);
        if (ret === 'true') {
            return true;
        } else if (ret === 'false') {
            return false;
        } else {
            return ret;
        }
    };

    qb_bridge.callbackFromNative = function (callbackId, args) {
        var callback = qb_bridge.callbacks[callbackId];
        var argsJson = JSON.parse(args);

        if (callback) {
            if (argsJson.succ) {
                callback.success && callback.success(argsJson.msg);
            } else {
                callback.fail && callback.fail(argsJson.msg);
            }

            if (!argsJson.keep) {
                delete qb_bridge.callbacks[callbackId];
            }
        }
    };

    qb_bridge.createEvent = function (type, data) {
        var event = document.createEvent('Events');
        event.initEvent(type, false, false);
        if (data) {
            for (var i in data) {
                if (data.hasOwnProperty(i)) {
                    event[i] = data[i];
                }
            }
        }
        return event;
    };

    qb_bridge.fireEvent = function (type, params) {
        var channel = window.qb_channel[type];
        if (channel) {
            var data = params && JSON.parse(params);
            var evt = qb_bridge.createEvent(type, data);
            channel.fire(evt);
        };
    }
});browser.define("browser.connection.getType",function(callback) {
  var stat = '';
  try {
    stat = qb_bridge.exec(null, null, "connection", "type", null);
  } catch (e) {
    console.debug(e);
  }
  callback(stat);
});browser.define("browser.device.getModel",function(callback){
  callback(qb_bridge.exec(null, null, "device", "model", null));
});browser.define("browser.device.getVersion",function(callback){
  callback(qb_bridge.exec(null, null, "device", "version", null));
});browser.define("browser.device.getPlatform",function(callback){
  callback(qb_bridge.exec(null, null, "device", "platform", null));
});browser.define("browser.device.vibrate", function(value){
	var params;
	if (value > 0)
		params = { times: value };
	else if (value)
		params = value;
	if (params)
		qb_bridge.exec(null, null, 'qb', 'vibrate', params);
});browser.define("browser.device.beep", function(times){
	qb_bridge.exec(null, null, 'qb', 'beep', { times: times });
});browser.define("browser.device.getMacAddress", function(callback){
	qb_bridge.exec(callback, null,"device","getMacAddress","");
});browser.define("browser.device.getAllInstalledApps", function(success, error){
  window.browser_device_getAllInstalledApps_succCallback = success || function() {};
  window.browser_device_getAllInstalledApps_errCallback = error || function() {};
  try {
    x5mtt.getAllInstalledApps(function(ret) {
      window.browser_device_getAllInstalledApps_succCallback(ret);
    });
  } catch(e) {
    window.browser_device_getAllInstalledApps_errCallback(e);
  }
});browser.define("browser.device.copy", function(strCopy, succCallback, errCallback){
   var opt = {'text':strCopy};
   try {
     qb_bridge.exec(null,null,"device","copy",opt);
     succCallback && succCallback();
   } catch (ex) {
     errCallback && errCallback(ex);
   }
});browser.define("browser.device.stopRecordAudio", function(){
	qb_bridge.exec(null,null,"device","stopRecordAudio",null);
});browser.define("browser.device.playAudio", function(){
	qb_bridge.exec(null,null,"device","playAudio",null);
});browser.define("browser.device.startRecordAudio", function(){
	qb_bridge.exec(null,null,"device","startRecordAudio",null);
});browser.define("browser.device.getstephistory", function(succCallback,options){
	return qb_bridge.exec(succCallback,null,"device","getstephistory",options);
});browser.define("browser.device.getstep", function(succCallback,errCallback){
	return qb_bridge.exec(succCallback,errCallback,"device","getstep",null);
});browser.define("browser.device.uploadFile", function(succCallback, errCallback, options){
	qb_bridge.exec(succCallback, errCallback,"device","uploadFile",options);
});browser.define("browser.device.requestPermission", function(succcb,options){
  	 var build = "823951";
  	 if(build >= "722945")
    {
		qb_bridge.exec(succcb,null,"device","requestPermission",options);
    }
  	else
   {
      if(typeof succcb == 'function')
      {
         succcb({"enable":true});
      }
   }
});browser.define("browser.device.getAndroidID", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback,"device","getAndroidID",options);
});browser.define("browser.device.checkPermission", function(succcb,options){
  	 var build = "823951";
  	 if(build >= "722945")
    {
		qb_bridge.exec(succcb,null,"device","checkPermission",options);
    }
  	else
   {
      if(typeof succcb == 'function')
      {
         succcb({"enable":true});
      }
   }
});browser.define("browser.device.getQIMEI", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback,"device","getQIMEI",options);
});browser.define("browser.device.getWifiInfo", function(callback){
  qb_bridge.exec(callback, null,"device","getWifiInfo","");
});browser.define("browser.screen.lockOrientation",function(orientation){
  qb_bridge.exec(null, null, "screen", "lockOrientation", { "orientation": orientation });
});browser.define("browser.screen.getOrientation",function(callback){
  callback(qb_bridge.exec(null, null, "screen", "orientation", null));
});browser.define("browser.screen.unlockOrientation",function(){
  qb_bridge.exec(null, null, "screen", "unlockOrientation", null);
});browser.define("browser.screen.getNightmodeEnabled", function(callback){
	callback(qb_bridge.exec(null, null, "skin", "nightmodeEnabled", null));
});browser.define("browser.screen.exitFullScreen", function(succCallback,errCallback){
  try{
  	succCallback&&succCallback( qb_bridge.exec(null, null, "screen", "exitFullScreen", null) );
  }catch(e) {
  	errCallback&&errCallback(e);
  }
});browser.define("browser.screen.requestFullScreen", function(succCallback, errCallback){
  try {
	succCallback&&succCallback(qb_bridge.exec(null, null, "screen", "requestFullScreen", null));
  } catch(ex){
  	errCallback&&errCallback(ex);
  }
});browser.define("browser.screen.fullscreenEnabled",function(callback){
  callback(qb_bridge.exec(null, null, "screen", "fullscreenEnabled", null));
});browser.define("browser.screen.requestPageNoTitle",  function(succCallback, errCallback) {
   var no_error = true;
	try {
		x5mtt.screen().requestPageNoTitle();
	} catch (e) {
      no_error = false;
		errCallback && errCallback(e);
	}
   if( no_error ) succCallback && succCallback();
});browser.define("browser.screen.cancelPageNoTitle",  function(succCallback, errCallback) {
   var no_error = true;
	try {
		x5mtt.screen().cancelPageNoTitle();
	}
   catch( e ) {
      no_error = false;
		errCallback && errCallback(e);
	}
   if( no_error ) succCallback && succCallback();
});browser.define("browser.screen.capturePage",  function(succCallback, errCallback, options) {
   qb_bridge.exec(succCallback, errCallback,"screen","capturePage",options);
});browser.define("browser.login.authorize", function(succCallback, errCallback, options) {
  var paramString = JSON.stringify(options);
	window.authorizeSuccCb = succCallback;
   window.authorizeErrCb = errCallback;
  	var cbSucc = function(callBackParam) {
   	window.authorizeSuccCb && window.authorizeSuccCb(callBackParam);
   	window.authorizeSuccCb = null;
    };
  	var cbError = function(callBackParam) {
   	window.authorizeErrCb && window.authorizeErrCb(callBackParam);
   	window.authorizeErrCb= null;
    };
	options["succCallback"]= String(cbSucc); 
   options["failCallback"]=String(cbError);
   qb_bridge.exec(null, null, "account", "authorize", options);
});browser.define("browser.login.getAccountInfo", function(succCallback, errCallback, options) {
  var callback = succCallback || function(info) {};
  var op = new Object();
  op["appid"]=options;
  var info = qb_bridge.exec(null, null, "account", "getAccountInfo", op);
  callback(info ? JSON.parse(info) : null);
});browser.define("browser.login.showLoginPanel", function (succCallback, errCallback, options) {
  if(!options) {
    options = new Object();
  }
  
	window.coolread_showLoginPanel_callback = succCallback || function (info) {};
  	options["succCallback"]= String(function (info){
      window.coolread_showLoginPanel_callback(info);
    });
  
   options["failCallback"]=String(errCallback);
 	qb_bridge.exec(null, null, "account", "showLoginPanel", options);
});browser.define("browser.login.getLoginInfo", function(succCallback, errCallback) {
  var no_error = true, info = null;
  try{
    var data = qb_bridge.exec(null, null, "account", "getLoginInfo", null);
    if(data) {
      info = JSON.parse(data);
    }
  }
  catch(e) {
    no_error = false;
    errCallback && errCallback(e);
  }
  if( no_error ) {
    succCallback && succCallback( info );
  }
});browser.define("browser.login.refreshToken", function(options, callback){
  window.refreshTokenCallback = callback;
  var cb = function(callBackParam){
    window.refreshTokenCallback && window.refreshTokenCallback(callBackParam);
    window.refreshTokenCallback = null;
  };
  options["succCallback"]=String(cb)
  qb_bridge.exec(null, null, "account", "refreshToken", options);
});browser.define("browser.login.getAuthorizeInfo", function(succCallback, errCallback, options) {
  var callback = succCallback || function(info) {};
  var info = qb_bridge.exec(null, null, "account", "getAuthorizeInfo", options);
  callback(info ? JSON.parse(info) : null); 
});browser.define("browser.login.logoutAuthorizeInfo", function(succCallback, errCallback, options) {
  var callback = succCallback || function(params) {};
  qb_bridge.exec(null, null, "account", "logoutAuthorizeInfo", options);
  var res = {res:0};
  callback(res ? res:null); 
});browser.define("browser.login.cpAuthorize", function(options, callback){
  options["succCallback"] = String(callback);
  qb_bridge.exec(null, null, "account", "cpAuthorize", options);
});browser.define("browser.login.enableAccountCookie", function(succCallback,errCallback,options){
  	 qb_bridge.exec(succCallback, errCallback, "account", "enableAccountCookie", options );
});browser.define("browser.login.getCpOpenid", function(options, callback){
  if(!options)
  {
    options = new Object();
  }
  options["succCallback"] = String(callback);
    qb_bridge.exec(null, null, "account", "getCpOpenid", options );
  
});browser.define("browser.bookshelf.getOfflineProgress", function (succCallback) {
    var callback;
    var callname = 'getOfflineProgress' + new Date().getTime();
    window[callname] = typeof succCallback == 'function' ? succCallback : '';
  	 var options = new Object();
  	 options["succCallback"]='function(o){window["' + callname + '"] && window["' + callname + '"](o);}';
  	 qb_bridge.exec(null,null,"novel","getOfflineProgress",options);
   
});browser.define("browser.bookshelf.openBook", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","openBook",options);
});browser.define("browser.bookshelf.openBookshelf", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","openBookshelf",options);
});browser.define("browser.bookshelf.offlineBook", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","offlineBook",options);
});browser.define("browser.bookshelf.add2bookshelf", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","add2bookshelf",options);
});browser.define("browser.bookshelf.getReaderInfo", function(succCallback,errCallback){
  var no_error = true, info = null;
  try{
    var data = qb_bridge.exec(null, null, "account", "getLoginInfo", null);
    if(data) {
      info = JSON.parse(data);
    }
  }
  catch(e) {
    no_error = false;
    errCallback && errCallback(e);
  }
  if( no_error ) {
    succCallback && succCallback( info );
  }
});browser.define("browser.bookshelf.getRecentlyRead", function (succCallback) {
    var callback;
    var callname = 'getRecentlyRead' + new Date().getTime();
    window[callname] = typeof succCallback == 'function' ? succCallback : '';
  	 var options = new Object();
  	options["succCallback"]= 'function(o){window["' + callname + '"] && window["' + callname + '"](o);}';
  	qb_bridge.exec(null,null,"novel","getrecentopenbook",options);
   
});

browser.define("browser.bookshelf.userInvalid", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","userInvalid",options);
});browser.define("browser.bookshelf.nativeLogin", function(suc, err){
  //x5.android.exec("login", options, suc, err)
  window['bknativeLogin'] = suc;
  var cbk = function(){
    nativeApi.getUserInfo(function(o){
      window['bknativeLogin'] && window['bknativeLogin'].call(null, o);
    })
  };
  if( isAndroidLight ){
    cbk += '';
  }
  mtt.callLogin(cbk, JSON.stringify({appID : '11028', supportType : 1}));  // supportType : 0--所有， 1--QQ， 2--微信
});browser.define("browser.bookshelf.payment", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","payment",options);
});browser.define("browser.bookshelf.getUserBookShelf", function (succCallback) {
    var callback;
    var callname = 'getUserBookShelf' + new Date().getTime();
    window[callname] = typeof succCallback == 'function' ? succCallback : '';
  	 var options = new Object();
  	 options["succCallback"]='function(o){window["' + callname + '"] && window["' + callname + '"](o);}';
  	 qb_bridge.exec(null,null,"novel","getUserBookShelf",options);
   
});browser.define("browser.bookshelf.getLoginInfo", function(suc, err){
  var loginInfo = "";
  var info = {};
  if( typeof x5mtt !== "undefined" ){
    loginInfo = qb_bridge.exec(null, null, "account", "getLoginInfo", null)+"";
    if(loginInfo == "undefined" || loginInfo == "{}"){
      info = {};
    }
    else{
      info = JSON.parse(loginInfo);
    }
    suc && suc(info);
    return info;
  }
  else{
    info = {};
    err && err(info);
    return info;
  }
});browser.define("browser.bookshelf.showToaster", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","showToaster",options);
});browser.define("browser.bookshelf.setBarTitle", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","setBarTitle",options);
});browser.define("browser.bookshelf.isInBookShelf", function (succCallback, errCallback, options) {
   
    var callname = 'isInBookShelf' + new Date().getTime();
    window[callname] = typeof succCallback == 'function' ? succCallback : '';
    var options = new Object();
  	 options["succCallback"]= 'function(o){window["' + callname + '"] && window["' + callname + '"](o);}';
    qb_bridge.exec(null,null,"novel","isinbookshelf",options);
});browser.define("browser.bookshelf.chapterList", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","chapterList",options);
});browser.define("browser.bookshelf.prepay", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","prepay",options);
});browser.define("browser.bookshelf.showSoftInput", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","showSoftInput",options);
});browser.define("browser.bookshelf.isNativeMode", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","isNativeMode",options);
});browser.define("browser.bookshelf.getAPI", function (){
    (function () {
        if (typeof mtt !== 'object'||!mtt) {
            return
        }
        var info;
        try{
          var params = mtt.getBrowserParam();
          info = eval('(' + params + ')');        
        }catch(e){}
        var _build = +"823951";
        var Qua = info.qua || "";
        var arr = Qua.match(/[0-9]{6}/g);
        var build = (arr && arr.length > 0) ? parseInt(arr[0]) : _build;
        var api = {
            openBookshelf : [5.2, "openbookshelf"],
            add2bookshelf : [5.2, "add2bookshelf"],
            showSoftInput : [5.7, "showsoftinput"],
            getUserBookShelf : [5.2, "getuserbookshelf"],
            openBook : [5.2, "openbook"],
            chapterList : [5.2, "chapterlist"],
            offlineBook : [5.2, "offlinebook"],
            getOfflineProgress : [5.2, "getofflineprogress"],
            setBarTitle : [5.2, "setbartitle"],
            payment : [5.5, "payment"],
            showToaster : [5.2, "showtoaster"],
            getRecentlyRead : [5.2, "getrecentopenbook"],
            isInBookShelf : [5.2, "isinbookshelf"],
            userInvalid : [5.2, "userInvalid"],
            prepay : [5.2, "prepay"],
            openUrlByBrowser : [6.1, "openUrlByBrowser"]
        };
        browser.bookshelf = browser.bookshelf || {};
        
        if(typeof qbbookshelf == 'object' && qbbookshelf && 'ReqBrowser' in qbbookshelf){
            for (var key in api) {
                if (build >= api[key][0] * 1E5 && !(key in browser.bookshelf)) {
                    (function (key) {
                        browser.define('browser.bookshelf.' + key, function (succCallback, errCallback, options) {
                            qbbookshelf.ReqBrowser(api[key][1], JSON.stringify(options), succCallback + '');
                        });
                    })(key);
                }
            }
        }

        var appID = '{"appID" : 13872}';
        if(typeof x5mtt == 'object' && x5mtt && (x5mtt.getAccountInfo||x5mtt.getLoginInfo)){
            browser.define("browser.bookshelf.getUserInfo", function (succCallback, errCallback, options) {
                var ret = '{"rtncode":-1}';
                if (x5mtt.getAccountInfo) {
                    ret = x5mtt.getAccountInfo(options || appID) || ret;
                } else{
                    ret = x5mtt.getLoginInfo() || ret;
                }
                succCallback(JSON.parse(ret));
            });
        }

        if (mtt.callLogin) {
            browser.define("browser.bookshelf.showLoginPanel", function (succCallback, errCallback, options) {
                mtt.callLogin(succCallback + ''); //低版本不需要参数
            });
        }
        
        if(mtt.getBrowserParam){
            browser.define("browser.bookshelf.getBrowserParam", function (succCallback, errCallback) {
                var params = mtt.getBrowserParam(),
                info = eval('(' + params + ')');
                succCallback(info);
            });
        }
        
        browser.define("browser.bookshelf.share", function (succCallback, errCallback, options) {
            if(typeof x5mtt == 'object' && x5mtt && x5mtt.share){
                x5mtt.share(JSON.stringify(options), succCallback);
            }else{
                qb_bridge.exec(succCallback, errCallback, "qb", "share", options);
            }
        });

        browser.bookshelf.qua = Qua;
        browser.bookshelf.build = build;
    })();
});browser.define("browser.bookshelf.getBrowserParam", function (succCallback, errCallback) {
    try {
        var params = qb_bridge.exec(null,null,"qb","getBrowserParam",null),
        info = eval('(' + params + ')');
        succCallback(info);
    } catch (e) {
        errCallback && errCallback({
            rtncode : -1,
            error : e
        });
    }
});browser.define("browser.bookshelf.gotoPage", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","gotoPage",options);
});browser.define("browser.bookshelf.openUrlByBrowser", function (succCallback, errCallback, options) {
  options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
  	qb_bridge.exec(null,null,"novel","openUrlByBrowser",options);
});browser.define("browser.bookshelf.payMonth", function (succCallback, errCallback, options) {
   options["succCallback"]= String(succCallback);
   options["errCallback"]= String(errCallback)
   qb_bridge.exec(null,null,"novel","showSoftInput",options);
});browser.define("browser.circle.hiddenCheckInView", function () {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "hiddenCheckInView",
                options: {},
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.hiddenCheckInView();
        }
    }
    else {
        circle.hiddenCheckInView();
    }
});browser.define("browser.circle.getCheckInRsq", function (succCallBack, errCallBack) {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "getCheckInRsq",
                options: {},
                succCallBack: succCallBack ? succCallBack.toString() : "",
                errCallBack: errCallBack ? errCallBack.toString() : "",
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.getCheckInRsq(succCallBack, errCallBack);
        }
    }
    else {
        circle.getCheckInRsq(succCallBack, errCallBack);
    }
});browser.define("browser.circle.showPublishEntry", function (options, callback) {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "showPublishEntry",
                options: options,
                callback:callback
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.showPublishEntry(JSON.stringify(options),callback);
        }
    }
    else {
        circle.showPublishEntry(JSON.stringify(options),callback);
    }
});browser.define("browser.circle.notifyFollowComplete", function(options,callback){
	qb_bridge.exec(callback,null,"circle","notifyFollowComplete",options)
});browser.define("browser.circle.startPublisher", function(options,callback){
	qb_bridge.exec(callback,null,"circle","startPublisher",options)
});browser.define("browser.circle.openInternalPage", function (options) {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "openInternalPage",
                options: options,
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.openInternalPage(JSON.stringify(options));
        }
    }
    else {
        circle.openInternalPage(JSON.stringify(options));
    }
});browser.define("browser.circle.showNativeFrame", function () {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "showNativeFrame",
                options: {},
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.showNativeFrame();
        }
    }
    else {
        circle.showNativeFrame();
    }
});browser.define("browser.circle.updateFollowState", function (options) {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "updateFollowState",
                options: options,
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.updateFollowState(JSON.stringify(options));
        }
    }
    else {
        circle.updateFollowState(JSON.stringify(options));
    }
});browser.define("browser.circle.setPageViewportTop", function () {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "setPageViewportTop",
                options: {},
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.setPageViewportTop();
        }
    }
    else {
        circle.setPageViewportTop();
    }
});browser.define("browser.circle.hideNativeFrame", function () {
    if (typeof (__REACT_WEB_VIEW_BRIDGE) != "undefined") {
        try {
            var message = {
                func: "hideNativeFrame",
                options: {},
            }
            window.postMessage(JSON.stringify(message))
        }
        catch (e) {
            circle.hideNativeFrame();
        }
    }
    else {
        circle.hideNativeFrame();
    }
});browser.define("browser.comic.taponmiddlearea", function(){
	qb_bridge.exec(null,null,"comic","taponmiddlearea",null);
});browser.define("browser.comic.taponheadarea", function(/*参数列表*/){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(null,null,"comic","taponheadarea",null);
});browser.define("browser.comic.didscrolltopage", function(option){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(null,null,"comic","didscrolltopage",option);
});browser.define("browser.comic.getinitinfo", function(){
	/*请在这里输入API的实现代码*/
     qb_bridge.exec(null,null,"comic","getinitinfo",null);
});browser.define("browser.comic.tapontailarea", function(/*参数列表*/){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(null,null,"commic","tapontailarea",null);
});browser.define("browser.comic.didscrolltochapter", function(option){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(null,null,"comic","didscrolltochapter",option);
});browser.define("browser.comic.previewLoadContent", function(options,callback){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(callback, null,"comic","previewLoadContent",options);
});browser.define("browser.comic.addBookShelf", function(option,callback){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(callback, null,"comic","addBookShelf",option);
});browser.define("browser.pay.showRechargePanel", function(options,callback){
	/*请在这里输入API的实现代码*/
  	return qb_bridge.exec(callback, null, "pay", "showRechargePanel", options);
});browser.define("browser.live.getVersion", function(options, callback){
   var version = qb_bridge.exec(callback, null, "live", "getVersion", options );
   if(callback)
   {
     callback(version);
   }
   return version;
});browser.define("browser.live.onUserSwitch", function(options, handler){
	var str = new Date().getTime();
  	window[str] = handler;
    var channel = qb_channel['onUserSwitch'];
    if (!channel) {
      	channel = qb_channel.create('onUserSwitch');
      	channel.onHasSubscribersChange = function () {
          	qb_bridge.exec(null, null, "live", "subscribeChanged", { numHandlers: this.numHandlers, type: "onUserSwitch",params:options });
      	}
    }
    channel.subscribe(handler);
});browser.define("browser.live.pay", function(options, callback){
  	 qb_bridge.exec(callback, null, "live", "pay", options );
});browser.define("browser.live.getBalance", function(options, callback){
	/*请在这里输入API的实现代码*/
  	 qb_bridge.exec(callback, null, "live", "getBalance", options );
});browser.define("browser.live.getUserInfo", function(options,callback){
	return qb_bridge.exec(callback, null, "live", "getUserInfo", options);
});browser.define("browser.live.refreshToken", function(options, callback){
       qb_bridge.exec(callback, null, "live", "refreshToken", options );
});browser.define("browser.live.recharge", function(options, callback){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(callback, null, "live", "recharge", options );
});browser.define("browser.live.showRechargePanel", function(options,callback){
	/*请在这里输入API的实现代码*/
  	return qb_bridge.exec(callback, null, "live", "showRechargePanel", options);
});browser.define("browser.live.login", function(options, callback){
       qb_bridge.exec(callback, null, "live", "login", options );
});browser.define("browser.live.isQQBrowserLogined", function(options,callback){
	qb_bridge.exec(callback, null, "live", "isQQBrowserLogined", options );
});browser.define("browser.download.getDownloadInfo", function(succCallback, errCallback, options){
	return qb_bridge.exec(succCallback, errCallback, "download", "getDownloadInfo", options);
});browser.define("browser.download.startDownload", function(options){
	return qb_bridge.exec(null, null, "download", "startDownloadAndInstall", options);
});browser.define("browser.download.getDownloadStatus", function(options){
	return qb_bridge.exec(null, null, "download", "getDownloadStatus", options);
});browser.define("browser.download.installApp", function(options, cb){
	return qb_bridge.exec(cb, null, 'download', 'installApp', options);
});browser.define("browser.download.pauseDownload", function(options){
	return qb_bridge.exec(null, null, "download", "pauseDownload", options);
});browser.define("browser.qqmarket.applyDeskTheme", function(options, cbSucc,cbFaild){
	qb_bridge.exec(cbSucc,cbFaild,"qqmarket","applyDeskTheme",options);
});
browser.define("browser.qqmarket.getDeskThemeState", function(options, cbSucc,cbFaild){
	qb_bridge.exec(cbSucc,cbFaild,"qqmarket","getDeskThemeState",options);
});
browser.define("browser.qbmarket.showQQMGuideDialog", function(options, cbSucc){
	qb_bridge.exec(cbSucc,null,"qqmarket","showQQMGuideDialog",options);
});browser.define("browser.qbmarket.historyBack", function(){
	qb_bridge.exec(null,null,"qqmarket","historyBack",null);
});browser.define("browser.qbmarket.validateToken", function(cbSucc,cbFaild,options){
	qb_bridge.exec(cbSucc,cbFaild,"qqmarket","validateToken",options);
});browser.define("browser.qbmarket.getDownloadInfo", function(succCallback, errCallback, options){
	return qb_bridge.exec(succCallback, errCallback, "qqmarket", "getDownloadInfo", options);
});browser.define("browser.qbmarket.downloadstatuschange", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel['onMarketDownloadStatusChange'];
	if (!channel){
		channel = qb_channel.create('onMarketDownloadStatusChange');
		channel.onHasSubscribersChange = function() {
			qb_bridge.exec(null, null, "qqmarket", "subscribeChanged", {numHandlers:this.numHandlers});
			}
	}
	channel.subscribe(handler);
});browser.define("browser.qbmarket.startDownload", function(options){
	return qb_bridge.exec(null, null, "qqmarket", "startDownloadAndInstall", options);
});browser.define("browser.qbmarket.pauseDownload", function(options){
	return qb_bridge.exec(null, null, "qqmarket", "pauseDownload", options);
});browser.define("browser.qbmarket.installApp", function(options, cb){
	return qb_bridge.exec(cb, null, 'qqmarket', 'installApp', options);
});browser.define("browser.qb.openUrlInBrowser", function(options){
  qb_bridge.exec(null,null,"qb","openUrlInBrowser",options);
});browser.define("browser.qb.userFeedback", function(options){
	
  	qb_bridge.exec(null,null,"qb","userFeedback",options);
});browser.define("browser.qb.beacon", function(options){
  	qb_bridge.exec(null,null,"qb","beacon",options);
});browser.define("browser.qb.showPushNotification", function(options){
	qb_bridge.exec(null, null,"push","showPushNotification",options);
});browser.define("browser.qb.tbslive", function(options, callback){
	return qb_bridge.exec(callback, callback, "qb", "tbslive", options);
});browser.define("browser.qb.test", function(){
	return qb_bridge.exec(null,null, "qb", "test", null);
});
browser.define("browser.video.playEpisode", function(params, succCallback, errCallback){
  var result = qb_bridge.exec(null,null,"video","playEpisode",params);
  succCallback && succCallback(result);
});browser.define("browser.video.getLastHistory",function(succCallback, errCallback){
     var result = qb_bridge.exec(null,null,"video","getLastHistory",null);
     succCallback && succCallback(result);
});browser.define("browser.video.getSpecificHistory", function(videoId, succCallback){
  	videoId = videoId.toString();
	info = qb_bridge.exec(null,null,"video","getSpecificHistory",videoId);
    succCallback && succCallback(info);
});browser.define("browser.video.doMultiCache", function(params){
	qb_bridge.exec(null,null,"video","doMultiCache",params);
});browser.define("browser.video.getFollowShows", function(videoId, succCallback){
    var param = {
      videoId: videoId
    };
    var result = qb_bridge.exec(null,null,"video","getFollowShows",param);
    if(result == "true")
	 {
		succCallback && succCallback(true);
	 }
	 else
	 {
		succCallback && succCallback(false);
	 }  

});browser.define("browser.video.playLastHistory", function(succCallback){
	qb_bridge.exec(null,null,"video","playLastHistory",null);
    succCallback && succCallback();
});browser.define("browser.video.doFollowShows", function(params, succCallback){
	 var result = qb_bridge.exec(null,null,"video","doFollowShows",params);
    succCallback && succCallback();
});browser.define("browser.video.deleteFollowShows", function(params, succCallback){
	 var result = qb_bridge.exec(null,null,"video","deleteFollowShows",params);
	succCallback && succCallback();
});browser.define("browser.video.getHistory", function(start, length, succCallback){
  var param = {
    start: start,
    length: length
  };
  var playHistory = JSON.parse(qb_bridge.exec(null,null,"video","getHistory",param));
  if(!playHistory) {
    return;
  }
  for(var i = 0; i < playHistory.history.length; i++) {
    playHistory.history[i] = JSON.parse(playHistory.history[i]);
  }
  succCallback && succCallback(playHistory);
});browser.define("browser.video.checkIsFollowsUpdate", function(succCallback){
  var result =qb_bridge.exec(null,null,"video","checkIsFollowsUpdate",null);
  if(result == "true")
	 {
		succCallback && succCallback(true);
	 }
	 else
	 {
		succCallback && succCallback(false);
	 }  
});browser.define("browser.video.canDownload", function(params, succCallback){
  var result = qb_bridge.exec(null,null,"video","canDownload",params);
  succCallback && succCallback(result);
});browser.define("browser.video.sniffVideoNotifyBrowser", function(uploadParams){
	x5mtt.sniffVideoNotifyBrowser(JSON.stringify(uploadParams));
});browser.define("browser.video.autoPlayNextVideo", function(succCallback){
	qb_bridge.exec(null,null,"video","autoPlayNextVideo",null);
  	succCallback && succCallback();
});browser.define("browser.video.playEpisodeNGX", function(params, succCallback, errCallback){
	browser.video.playEpisode(params, succCallback, errCallback);
});browser.define("browser.video.sniffHtml5Video", function(webUrl, clarity, callBack){
  window.sniffHtml5VideoCallback = callBack;
  var cbSucc = function(callBackParam) {
    window.sniffHtml5VideoCallback && window.sniffHtml5VideoCallback(callBackParam);
    window.sniffHtml5VideoCallback = null;
  };
  var param = {
      weburl: webUrl,
      cla:clarity,
      callback:String(cbSucc)
    };
  var result = qb_bridge.exec(null,null,"video","sniffVideoUrl",param);
});browser.define("browser.video.canSniff", function(params, succCallback){
  var result = qb_bridge.exec(null,null,"video","canSniff",params);
  succCallback && succCallback(result);
});browser.define("browser.video.playEpisodeWithSetNum", function(params, succCallback, errCallback){
	browser.video.playEpisode(params, succCallback, errCallback);
});browser.define("browser.video.playEpisodeWithCallback", function(params, succCallback,errCallback){
  params["callback"]=String(succCallback);
  var result = qb_bridge.exec(null,null,"video","playEpisodeWithCallback",params);
  succCallback && succCallback(result);
});browser.define("browser.video.playRecommendVideo", function(params){
  var paramString = JSON.stringify(params);
  mttadrvideo.playRecommendVideo(paramString);
});browser.define("browser.video.canPlayTenVideo", function(){
	return true;
});browser.define("browser.event.removeEventHandler", function(type,handler){
  	if(!type || !handler) return;
	var channel = qb_channel["on" + type];
  	if(channel){
      	channel.unsubscribe(handler);
    }
});browser.define("browser.event.volumedown", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel["onvolumedown"];
  	if (!channel) {
      	channel = qb_channel.create("onvolumedown");
      	channel.onHasSubscribersChange = function(){
			qb_bridge.exec(null, null, "qb", "subscribeChanged", { numHandlers: this.numHandlers, type: "onvolumedown" });
      	};
    }
  	channel.subscribe(handler);
});browser.define("browser.event.volumeup", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel["onvolumeup"];
  	if (!channel) {
      	channel = qb_channel.create("onvolumeup");
      	channel.onHasSubscribersChange = function(){
			qb_bridge.exec(null, null, "qb", "subscribeChanged", { numHandlers: this.numHandlers, type: "onvolumeup" });
      	};
    }
  	channel.subscribe(handler);
});browser.define("browser.event.connectionchange", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
    var channel = qb_channel['onconnectionchange'];
    if (!channel) {
      	channel = qb_channel.create('onconnectionchange');
      	channel.onHasSubscribersChange = function () {
          	qb_bridge.exec(null, null, "connection", "subscribeChanged", { numHandlers: this.numHandlers });
      	}
    }
    channel.subscribe(handler);
});browser.define("browser.event.orientationchange", function(handler){
  	var str = new Date().getTime();
  	window[str] = handler;
    var channel = qb_channel['onorientationchange'];
    if (!channel) {
      	channel = qb_channel.create('onorientationchange');
      	channel.onHasSubscribersChange = function () {
          	qb_bridge.exec(null, null, "screen", "subscribeChanged", { numHandlers: this.numHandlers });
      	}
    }
    channel.subscribe(handler);
});browser.define("browser.event.downloadstatuschange", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel['ondownloadstatuschange'];
	if (!channel){
		channel = qb_channel.create('ondownloadstatuschange');
		channel.onHasSubscribersChange = function() {
			qb_bridge.exec(null, null, "download", "subscribeChanged", {numHandlers:this.numHandlers});
			}
	}
	channel.subscribe(handler);
});browser.define("browser.event.onloginUserSwitch", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
    var channel = qb_channel['onloginUserSwitch'];
    if (!channel) {
      	channel = qb_channel.create('onloginUserSwitch');
      	channel.onHasSubscribersChange = function () {
          	qb_bridge.exec(null, null, "qb", "subscribeChanged", { numHandlers: this.numHandlers, type: "onloginUserSwitch" });
      	}
    }
    channel.subscribe(handler);
});browser.define("browser.event.onARFrameUpload", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel['onARFrameUpload'];
	if (!channel){
		channel = qb_channel.create('onARFrameUpload');
		channel.onHasSubscribersChange = function() {
			qb_bridge.exec(null, null, "ar", "subscribeUpload", {numHandlers:this.numHandlers});
			}
	}
	channel.subscribe(handler);
});browser.define("browser.event.onARRecoginitionResult", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel['onARRecoginitionResult'];
	if (!channel){
		channel = qb_channel.create('onARRecoginitionResult');
		channel.onHasSubscribersChange = function() {
			qb_bridge.exec(null, null, "ar", "subscribeRecognition", {numHandlers:this.numHandlers});
			}
	}
	channel.subscribe(handler);
});browser.define("browser.event.onAREngineStatusChanged", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel['onAREngineStatusChanged'];
	if (!channel){
		channel = qb_channel.create('onAREngineStatusChanged');
		channel.onHasSubscribersChange = function() {
			qb_bridge.exec(null, null, "ar", "subscribeEngineStatus", {numHandlers:this.numHandlers});
			}
	}
	channel.subscribe(handler);
});browser.define("browser.event.onFaceDetected", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel['onFaceDetected'];
	if (!channel){
		channel = qb_channel.create('onFaceDetected');
		channel.onHasSubscribersChange = function() {
			qb_bridge.exec(null, null, "ar", "subscribeFaceDetected", {numHandlers:this.numHandlers});
		}
	}
	channel.subscribe(handler);
});browser.define("browser.event.getFrameFeaturesPoints", function(handler){
	var str = new Date().getTime();
  	window[str] = handler;
  	var channel = qb_channel['getFrameFeaturesPoints'];
	if (!channel){
		channel = qb_channel.create('getFrameFeaturesPoints');
		channel.onHasSubscribersChange = function() {
			qb_bridge.exec(null, null, "ar", "getFrameFeaturesPoints", {numHandlers:this.numHandlers});
		}
	}
	channel.subscribe(handler);
});browser.define("browser.app.isInstallApk", function(callback,options){
  	var code = qb_bridge.exec(null, null,"app","isApkInstalled",options);
  
    if(code == "1") {
		callback && callback(true);
    } else {
      callback && callback(false);
    }
});browser.define("browser.app.toast", function(text, duration){
	qb_bridge.exec(null, null, "qb", "toast", { text: text, duration: duration });
});browser.define("browser.app.getQua", function(callback){
	callback(qb_bridge.exec(null, null, "qb", "qua", null));
});browser.define("browser.app.getGeoLocation", function(succCallback, errCallback) {
  var dt = +new Date();
  var suc = 'geoSuc' + dt;
  var err = 'geoErr' + dt;
  window[suc] = succCallback;
  window[err] = errCallback|| function(){};
  window.x5mtt.getGeolocation('{"cbSuccess":"' + suc + '","cbError":"' + err + '"}');
});browser.define("browser.app.share", function(options,callback){
    callback = callback || function(){};
 	     if (typeof options === 'object') {
      if (options.title && options.description && options.img_url) {
        options.content_type = 1;
      } else {
        options.content_type = 0;
      }
    }
    options["cb"]= String(callback);
    qb_bridge.exec(null,null,"share","share",options);
});browser.define("browser.app.getAppVersion", function(callback){
	callback(qb_bridge.exec(null, null, "qb", "appVersion", null));
});browser.define("browser.app.loadAppUrl", function(succCallback, errCallback,options){
	var opt = {
                appid: options.key,
                url: options.url,
                position: options.position
            };

            //4.1版本开始接口参数变成json字符串形式 可以传入postion参数
            try
            {
                qb_bridge.exec(null, null,"app","loadAppUrl",opt);
                succCallback && succCallback();                    
            }
            catch(e)
            {
                errCallback && errCallback({code:-1,message:e.name + ':' + e.message});
            }           
});browser.define("browser.app.getInstalledApps", function(succCallback, errCallback){
	var err;
  	try{
      if(qb_bridge != undefined) {
    		var ret =  qb_bridge.exec(null, null,"app","checkInstalledApp",null).split('|');
    		succCallback && succCallback(ret);
  		} else {
          	err = {code:-1,message:"qb_bridge is undifined"};
    	  	errCallback && errCallback(err);
  		}
  	}catch(e){
      	err = {code:-1,message:e.name + ':' + e.message};
  		errCallback && errCallback(err);
  	}
  
});browser.define("browser.app.checkInstalledApp", function(succCallback, errCallback, options) {
  var apps = qb_bridge.exec(null, null,"app","checkInstalledApp",options).split('|');
    
  for (var i = 0, l = apps.length; i < l; i++) {
    if (apps[i] == options.id) {
      return succCallback(true);
    }
  }
  
  return succCallback(false);
});browser.define("browser.app.installApp", function(succCallback, errCallback, options) {
  if(typeof qb_bridge !== "undefined"){
  	window.browser_app_installApp_succCallback = succCallback || function() {};
  	window.browser_app_installApp_errCallback = errCallback || function() {};
    if(typeof T5Kit !== "undefined") // 兼容"Q立方"和早期的下饭视频
    {
      T5Kit.asyncInstallSucc = succCallback || function() {};
      T5Kit.asyncInstallError = errCallback || function() {};
    }
  	options["succCallback"] = String(function () { window.browser_app_installApp_succCallback(); });
	options["errCallback"] = String(function (err) { window.browser_app_installApp_errCallback(err); });
	qb_bridge.exec(null, null,"app","asyncInstall",options);
  }else{
  	errCallback && errCallback({code:-1,message:'qb_bridge is undefined'});
  }
  
});browser.define( "browser.app.getBrowserParam", function( succCallback, errCallback ) {
  var no_error = true, info = null;
  try {
    info = JSON.parse( qb_bridge.exec(null,null,"qb","getBrowserParam",null) );
  }
  catch( e ) {
    no_error = false;
    errCallback && errCallback({code: -1, message: e.message});
  }
  if( no_error ) succCallback( info );
});browser.define("browser.app.canShareTo", function(options,callback){
  callback(qb_bridge.exec(null,null,"share","canShareTo",options));
});browser.define("browser.app.runApk", function(packagename){
  x5mtt.runApk(JSON.stringify({
     packagename: packagename
  }));
});browser.define("browser.app.openUrl", function(succCallback, errCallback,options){
  options["succCallback"] = String(succCallback);
  options["errCallback"] = String(errCallback)
	qb_bridge.exec(null, null, "qb", "openUrl", options);
});browser.define("browser.app.getApkInfo", function(callback,packagename){
  	var info = JSON.stringify(x5mtt.packages().getSingleApp(packagename));
    callback(info);
});browser.define("browser.app.isLinkOnDesktop", function(options,cbSucc,cbError){
  qb_bridge.exec(cbSucc, cbError, "app", "isLinkOnDesktop", options);
});browser.define("browser.app.doTokenFeature", function(callback, options){
  	qb_bridge.exec(callback, function(){}, "push", "tokenFeature", options);
});browser.define("browser.app.sendLinkToDesktop", function(options, cbSucc, cbError){
  qb_bridge.exec(cbSucc, cbError, "app", "sendLinkToDesktop", options);
});browser.define("browser.app.getQua2", function(callback){
	callback(qb_bridge.exec(null, null, "qb", "qua2", null));
});browser.define("browser.app.historyBack", function() {
  history.back();
});browser.define("browser.app.openInNewWindow", function(succCallback, errCallback, options){
	x5.exec(succCallback, errCallback, 'usercenter', 'openInNewWindow', [options])
});browser.define("browser.app.getOverScrollState", function(callback){
	if( typeof callback === 'function' ){
      try{
    var ret = JSON.parse(window.qb_bridge.exec(null, null, 'app','isOverScrollEnable', null));
    var state = ret.state || false;
    callback(state);
      }
      catch(e){console.error(e);}
  }
});browser.define("browser.app.setShareInfo", function(options, callback/*参数列表*/){
	var _toString = Object.prototype.toString,
		_cb = _toString.call(callback) === '[object Function]' ? callback : function () {},
		_opt = options;

	if(_toString.call(_opt) !== '[object Object]') {
		_cb({code: 1, msg: 'options 参数错误，必须为Object'});
	}
	else if (_toString.call(_opt.title) !== '[object String]') {
		_cb({code: 2, msg: 'options.title 参数错误，必须为String'});
	}
	else {
		if (_toString.call(window.browser.execWebFn) !== '[object Object]') {
			Object.defineProperty(window.browser, 'execWebFn', {value: {}});
		}
      
      _opt['content_type'] = 1;
      window.browser.execWebFn.shareInfoOptions = _opt;

		if (_toString.call(window.browser.execWebFn.customQbMenuShareInfo) !== '[object Function]') {
			Object.defineProperty(window.browser.execWebFn, 'customQbMenuShareInfo', {value: function (options/*终端传递过来的参数对象*/) {
				return JSON.stringify(window.browser.execWebFn.shareInfoOptions);
			}});
		}

		_cb({code: 0, msg: '设置成功'});
	}
});browser.define("browser.app.openInMainBrowseWindow", function(succCallback, errCallback, options){
	x5.exec(succCallback, errCallback, 'usercenter', 'openInMainBrowseWindow', [options])
});browser.define("browser.app.getThrdCallPid", function(succCallback, errCallback) {
  var no_error = true,
    appId;
  try {
    appId =qb_bridge.exec(null,null,"qb","getThrdCallPid",options);
  } catch (e) {
    no_error = false;
    errCallback && errCallback(e);
  }
  no_error && succCallback && succCallback(appId);
  return appId;
});browser.define("browser.app.setCurrentWindowTitle", function(succCallback, errCallback, options){
	x5.exec(succCallback, errCallback, 'usercenter', 'setCurrentWindowTitle', [options])
});browser.define("browser.app.getRecentRunningTask", function(options, cbSucc,cbFaild){
	qb_bridge.exec(cbSucc,cbFaild,"app","getRecentRunningTask",options);
});browser.define("browser.app.setOverScrollState", function(isOpen){
  var param = {"isOpen":isOpen};
  try{
	window.qb_bridge.exec(null, null, 'app','setOverScrollEnable', param);
  }
  catch(e){console.error(e)}
});browser.define("browser.app.showsoftinput", function(options){
	qb_bridge.exec(null,null,"app","showsoftinput",options);
});browser.define("browser.app.openUrlInWechat", function(options, cbSucc,cbFaild){
	qb_bridge.exec(cbSucc,cbFaild,"app","openUrlInWechat",options);
});browser.define("browser.app.deeplinkCheckInstallation", function(param, callback) {
	window.x5mtt_deeplink_checkinstallation_callback = callback;
	window.x5mtt.deeplink().isInstalled(param, function(p){
		window.x5mtt_deeplink_checkinstallation_callback(p);});
});browser.define("browser.app.deeplinkSetDownloadable", function(param){
	return window.x5mtt.deeplink().deeplinkSetDownloadable(param);
});browser.define("browser.app.openPhotoBrowser", function(urls, index, style){
	/*请在这里输入API的实现代码*/
  var optionArray = new Object();
  optionArray["urls"]=urls;
  optionArray["index"]=index;
  optionArray["style"]=style;
  optionArray["httpRefer"]=location.href;
  qb_bridge.exec(null,null,"image","openImageReader",optionArray);
});browser.define("browser.app.openImageReaderWithDelete", function(urls, index, httpRefer, succFun){
	/*请在这里输入API的实现代码*/
    var optionArray = new Object();
  optionArray["urls"]=urls;
  optionArray["index"]=index;
  optionArray["httpRefer"]=httpRefer;
  qb_bridge.exec(succFun,null,"image","openImageReaderWithDelete",optionArray);
});browser.define("browser.app.pushOnOff", function(){
	return qb_bridge.exec(null, null, "qb", "pushOnOff", null);
});browser.define("browser.app.turnToSysPush", function(){
	return qb_bridge.exec(null,null,"app","turnToSysPush",null);
});browser.define("browser.app.sysPushOnOff", function(){
	return qb_bridge.exec(null,null,"app","sysPushOnOff",null);
});browser.define("browser.app.switchOnQbPush", function(){
	return qb_bridge.exec(null,null,"app","switchOnQbPush",null);
});browser.define("browser.app.addCardToWechat", function(options, cbSucc, cbError){
	qb_bridge.exec(cbSucc, cbError, "app", "addCardToWechat", options);
});
browser.define("browser.app.showAlertDialog", function(callback, options){
 	qb_bridge.exec(callback, null, "app", "showAlertDialog", options);
});    browser.define("browser.coolread.openPicView", function (optionsOrUrl, urls, index, x, y, width, height) {
        if (window.__REACT_WEB_VIEW_BRIDGE) { // RN
            window.postMessage(JSON.stringify({
                func: 'coolread.openPicView',
                data: {
                    urls: urls,
                    index: index,
                    x: x,
                    y: y,
                    width: width,
                    height: height
                }
            }));
            return;
        }
        var options = typeof optionsOrUrl == "object" ? optionsOrUrl : {
            url: optionsOrUrl,
            urls: urls,
            index: index,
            x: x,
            y: y,
            width: width,
            height: height
        };
        qb_bridge.exec(null, null, "coolread", "openPicView", options);
    });browser.define("browser.coolread.openNews", function(url) {
  reader.ReqBrowser("openNews", JSON.stringify({url: url}), String(function() {}));
});browser.define("browser.coolread.openCurrentChannel", function(url) {
  if (typeof reader.openCurrentChannelByUrl !== "undefined") {
    reader.openCurrentChannelByUrl(url);
  } else {
    //reader.openCurrentChannel();
    location.href = url;
  }
});browser.define("browser.coolread.openSource", function() {
  reader.openWebSourceInCurWindow();
});browser.define("browser.coolread.checkInstalledApp", function(succCallback, errCallback, options) {
  window.coolread_checkInstalledApp_callback = succCallback || function(installed) {};
  reader.ReqBrowser("checkInstall", JSON.stringify(options), String(function(params) {
    window.coolread_checkInstalledApp_callback((typeof params === 'object' ? params : JSON.parse(params)).resCode === 1 ? true : false); // {"resCode": -2(appId must larger than 0) | -1(uninstalled) | 1(installed)}
  }));
});browser.define("browser.coolread.openShare", function() {
  reader.openShare();
});browser.define("browser.coolread.updateCmtNum", function(num) {
  reader.ReqBrowser("updateCmtNum", JSON.stringify({num: num}), String(function() {}));
});browser.define("browser.coolread.getTitle", function(id, callback, siteId) {
  callback = callback || function(data) {};
  if (!window.reader) {
    callback();
    return;
  }
  window.coolread_getTitle_callback = callback;
  reader.ReqBrowser("getTitle", JSON.stringify({articleId: id, cId: siteId}), String(function(data) {
    window.coolread_getTitle_callback(data); // {"title": "", "time": "", "cmtNum": 0, "srcName": "", "offline": true}
  }));
});browser.define("browser.coolread.getContent", function(id, callback, siteId) {
  callback = callback || function(data) {};
  if (!window.reader) {
    callback();
    return;
  }
  window.coolread_getContent_callback = callback;
  reader.ReqBrowser("getContent", JSON.stringify({articleId: id, cId: siteId}), String(function(data) {
    window.coolread_getContent_callback(data); // {"content": "{html}", title: "", "time": "", cmtNum: 0, srcName: ""}
  }));
});browser.define("browser.coolread.isInstallApk", function(callback, options) {
  window.coolread_isInstallApk_callback = callback || function(installed) {};
  reader.ReqBrowser("isApkInstalled", JSON.stringify(options.packagename ? options : {packagename: options.apkKey || options}), String(function(params) {
    window.coolread_isInstallApk_callback((typeof params === 'object' ? params : JSON.parse(params)).resCode === 1 ? true : false); // {"resCode": -1(uninstalled) | 1(installed)}
  }));
});browser.define("browser.coolread.historyBack", function() {
  reader.historyBack();
});browser.define("browser.coolread.picViewUpdate", function(options) {
   qb_bridge.exec(null, null, "coolread", "picViewUpdate", options);
});browser.define("browser.coolread.getSelectedCity", function(resolve, reject) {
	window.coolread_getSelectedCity_resolve = resolve || function() {};
  
  qb_bridge.exec(null, null, "coolread", "getSelectedCity", {func : String(function(city) {
		if (typeof city == "string") {
			try {
				city = JSON.parse(city);
			} catch (e) {
				console.error(e);
			}
		}
		window.coolread_getSelectedCity_resolve(city);
  })});	
});browser.define("browser.coolread.openExternalPage", function (url) {
    if (window.__REACT_WEB_VIEW_BRIDGE) { // RN
        window.postMessage(JSON.stringify({ func: 'coolread.openExternalPage', data: url }));
        return;
    }
    if (window.reader && window.reader.openExternalPage) {
        window.reader.openExternalPage(JSON.stringify({ // 兼容视频场景，不要随便删除
            url: url
        }));
        return;
    }
    qb_bridge.exec(null, null, "coolread", "openExternalPage", { url: url });
});browser.define("browser.coolread.pullFreshEnd", function(type, msg) {
	reader.pullFreshEnd(JSON.stringify({
		type: type,
		msg: msg
	}));
});browser.define("browser.coolread.setSelectedCity", function(city) {
   qb_bridge.exec(null, null, "coolread", "setSelectedCity", city);
});browser.define("browser.coolread.openInternalPage", function(options) {
   qb_bridge.exec(null, null, "coolread", "openInternalPage", options);
});browser.define("browser.coolread.setWebViewHeight", function(height) {
	reader.setWebViewHeight(JSON.stringify({
		height: height
	}));
});browser.define("browser.coolread.preloadArticle", function(url) {
	reader.preloadArticle(JSON.stringify({
		url: url
	}));
});browser.define("browser.coolread.getPageStatus", function(callback) {
	window.coolread_getPageStatus_cbk = callback;
	reader.getPageStatus(String(function(status) {
		window.coolread_getPageStatus_cbk(status);
	}));
});browser.define("browser.coolread.getSubscribedTags", function(){
	/*弃用*/
});browser.define("browser.coolread.setPageStatus", function(options) {
	reader.setPageStatus(JSON.stringify(options));
});browser.define("browser.coolread.setPostInfo", function (data) {
    if (window.__REACT_WEB_VIEW_BRIDGE) { // RN
        window.postMessage(JSON.stringify({ func: 'coolread.setPostInfo', data: data }));
        return;
    }
    if (window.reader && window.reader.setPostInfo) { // 视频场景
        window.reader.setPostInfo(JSON.stringify(data));
        return;
    }
    qb_bridge.exec(null, null, "coolread", "setPostInfo", data);
});    browser.define("browser.coolread.setCommentInfo", function (data) {
        if (window.__REACT_WEB_VIEW_BRIDGE) {
            window.postMessage(JSON.stringify({ func: 'coolread.setCommentInfo', data: data }));
            return;
        }
        qb_bridge.exec(null, null, "coolread", "setCommentInfo", data);
    });browser.define("browser.coolread.openNewsPage", function(optionsOrUrl1, url2, qbUrl, cmtNum, cmtUrl) {
	var options = typeof optionsOrUrl1 == "object" ? optionsOrUrl1 : {
		primary: optionsOrUrl1,
		secondary: url2,
		qbUrl: qbUrl,
		cmtNum: cmtNum || "",
		cmtUrl: cmtUrl || ""
	};
   qb_bridge.exec(null, null, "coolread", "openNewsPage", options);
});browser.define("browser.coolread.toggleSubscription", function (data, callback) {
    if (window.__REACT_WEB_VIEW_BRIDGE) {
        window.postMessage(JSON.stringify({
            func: 'coolread.toggleSubscription',
            data: data,
        }));
        return;
    }
    var key = Date.now();
    window[key] = callback;

    data.callback = String(function (result) {
        window[key](result);
        delete window[key]
    }).replace('key', key);

    qb_bridge.exec(null, null, "coolread", "toggleSubscription", data);
});
browser.define("browser.coolread.pullFreshStart", function() {
	reader.pullFreshStart();
});    browser.define("browser.coolread.openCommentPanel", function (data) {
        if (typeof data !== 'object') {
            data = { referId: '', placeholder: '' };
        }
        if (window.__REACT_WEB_VIEW_BRIDGE) { // RN
            window.postMessage(JSON.stringify({ func: 'coolread.openCommentPanel', data: data }));
            return;
        }
        // 优先使用 reader，兼容视频场景（浮层）
        if (window.reader && window.reader.openCommentPanel) {
            window.reader.openCommentPanel(JSON.stringify(data));
            return;
        }
        qb_bridge.exec(null, null, "coolread", "openCommentPanel", data);
    });browser.define("browser.coolread.pushDataFinished", function(){
	qb_bridge.exec(null, null, "coolread", "pushDataFinished", null);
});    browser.define("browser.coolread.openCommentPage", function (data) {
        if (window.__REACT_WEB_VIEW_BRIDGE) { // RN
            window.postMessage(JSON.stringify({ func: 'coolread.openCommentPage', data: data }));
            return;
        }
        window.reader.openCommentPage(JSON.stringify(data));
    });browser.define("browser.env.height", 2560);browser.define("browser.env.osVersion", "8.0.0");browser.define("browser.env.softType", "QBX");browser.define("browser.env.platForm", "ADR");browser.define("browser.env.channel", -1);browser.define("browser.env.coreName", "BK");browser.define("browser.env.machine", "ALP-AL00");browser.define("browser.env.version", 82);browser.define("browser.env.subPlatForm", "ADR");browser.define("browser.env.coreVersion", "030000");browser.define("browser.env.subVersion", "GA");browser.define("browser.env.width", 1440);browser.define("browser.env.qua", "");browser.define("browser.env.qua2", "QV=3&PL=ADR&PR=QB&PP=com.tencent.mtt&PPVN=8.2.0.3951&TBSVC=43100&CO=BK&COVC=030000&PB=GE&VE=GA&DE=PHONE&CHID=0&LCID=9397&MO= ALP-AL00 &RL=1440*2560&OS=8.0.0&API=26");browser.define("browser.env.build", "823951");browser.define("browser.audio.pausePlay", function(succCallback, errCallback){
	qb_bridge.exec(succCallback, errCallback,"audio","pausePlay", null);
});browser.define("browser.audio.resumePlay", function(succCallback, errCallback){
	qb_bridge.exec(succCallback, errCallback,"audio","resumePlay", null);
});browser.define("browser.audio.playMusic", function(params, succCallback, errCallback){
	qb_bridge.exec(succCallback, errCallback,"audio","playMusic",params);
});browser.define("browser.audio.getPlayingSongInfo", function(succCallback, errCallback){
	qb_bridge.exec(succCallback, errCallback,"audio","getPlayingSongInfo", null);
});browser.define("browser.card.addNaviCard", function(options, cbSucc, cbError){
	qb_bridge.exec(cbSucc, cbError, "navicard", "addNaviCard", options);
});browser.define("browser.card.isNaviCardExist", function(options, cbSucc, cbError){
	qb_bridge.exec(cbSucc, cbError, "navicard", "isNaviCardExist", options);
});browser.define("browser.card.getSkinTheme", function(){
	qb_bridge.exec(null, null, "navicard", "getSkinTheme", null);
});browser.define("browser.startpage.requestRefreshCard", function(callback, options){
	callback(mtt.requestRefreshCard(options.cardID));
});browser.define("browser.startpage.notifyNaviCardRelayout", function(){
	try {
      qb_bridge.exec(null, null, "navicard", "notifyNaviCardRelayout", "");
    } catch(e) {
    }
});browser.define("browser.startpage.getSwitchStatus", function(succCallback, errCallback, options){
	try {
      var result = qb_bridge.exec(null, null, "navicard", "getSwitchStatusSync", options);
      if (typeof result == "string") {
        result = JSON.parse(result);
      }
      succCallback && succCallback(result);
    } catch(e) {
      errCallback && errCallback();
    }
});browser.define("browser.startpage.addQuickLinkFromBookmark", function(succCallback, errCallback){
	if(typeof qb_bridge !== "undefined"){
    	qb_bridge.exec(null, null,"qb","addQuickLinkFromBookmark",null);
    }
    else
    {
        errCallback && errCallback();
    }
});browser.define("browser.startpage.addQuickLinkFromInput", function(succCallback, errCallback){
	if(typeof qb_bridge !== "undefined"){
    	qb_bridge.exec(null, null,"qb","addQuickLinkFromInput",null);
    }
    else
    {
        errCallback && errCallback();
    }
});browser.define("browser.startpage.addQuickLinkFromHistory", function(succCallback, errCallback){
	if(typeof qb_bridge !== "undefined"){
    	qb_bridge.exec(null, null,"qb","addQuickLinkFromHistory",null);
    }
    else
    {
        errCallback && errCallback();
    }
});browser.define("browser.startpage.switchToCity", function(succCallback, errCallback, options){
   try {
     x5mtt.notifyClientData("lifeservice", JSON.stringify(options));
     succCallback && succCallback();
   } catch (ex) {
     errCallback && errCallback(ex);
   }
});browser.define("browser.ar.getARCameraStatus", function(){
  return qb_bridge.exec(null, null, "ar", "getARCameraStatus", {});
});browser.define("browser.ar.registerARRecognitionTarget", function(options, callback){
	return qb_bridge.exec(callback, callback, "ar", "registerARRecognitionTarget", options);
});browser.define("browser.ar.removeARMarker", function(options){
	return qb_bridge.exec(null, null, "ar", "removeARMarker", options);
});browser.define("browser.ar.addARMarkerWithURL", function(options, callback){
	return qb_bridge.exec(callback, callback, "ar", "addARMarkerWithURL", options);
});browser.define("browser.ar.cleanARMarker", function(){
  return qb_bridge.exec(null, null, "ar", "cleanARMarker", {});
});browser.define("browser.ar.openExternalURL", function(options){
  qb_bridge.exec(null, null, "ar", "openExternalURL", options);
});browser.define("browser.ar.initAREngine", function(callback){
  return qb_bridge.exec(callback, callback, "ar", "initAREngine", {});
});browser.define("browser.ar.setARSnapPic", function(options){
  qb_bridge.exec(null, null, "ar", "setARSnapPic", options);
});

browser.define("browser.ar.faceRecognition", function(options, callback){
	return qb_bridge.exec(callback, callback, "ar", "faceRecognition", options);
});browser.define("browser.ar.removeFeaturePointsListener", function(){
  return qb_bridge.exec(null, null, "ar", "removeFeaturePointsListener", {});
});browser.define("browser.ar.addFeaturePointsListener", function(){
  return qb_bridge.exec(null, null, "ar", "addFeaturePointsListener", {});
});browser.define("browser.weather.getweatherinfo", function(succcb,options){
	return qb_bridge.exec(succcb,null,"weather","getWeatherInfo",options);
});browser.define("browser.weather.syncweatherinfo", function(options){
	qb_bridge.exec(null,null,"weather","syncWeatherInfo",options);
});browser.define("browser.distort.openUrlAndDistort", function(options){
	qb_bridge.exec(null,null,"distort","openUrlAndDistort",options);
});
browser.define("browser.x5gameplayer.logout", function(info,callback){
	/*请在这里输入API的实现代码*/
  	qb_bridge.exec(callback, null, "x5gameplayer", "logout", info );
});browser.define("browser.x5gameplayer.run", function(options){
       var obj = {
         "gameId" : options.gameId || 'test',
         "engineName" : options.engineName,
         "localDebug" : options.localDebug,
         "orientation": options.orientation,
         "gameName": options.gameName,
         "gameIconUrl": options.gameIconUrl,
         "gameUrl": options.gameUrl,
         "runUrl": options.runUrl || '',
         "ext": options.ext
       }
       qb_bridge.exec(null, null, "x5gameplayer", "run", obj );
});browser.define("browser.x5gameplayer.exit", function(){
	qb_bridge.exec(null, null, "x5gameplayer", "exit", null);
});browser.define("browser.x5gameplayer.share", function(options,callback){
      obj = {
       "url" : options.url,    //分享后点击的页面url
       "title" : options.title,    //分享界面的标题
       "description" : options.description || '',    //分享界面的描述
       "img_url" : options.imgUrl || '',    //分享内容插图url
       "img_title" : options.imgTitle || '',    //分享内容插图的标题
       "cus_txt" : options.cusTxt || '',    //本地sharewindow编辑框中默认填写的内容
       "to_app" : options.toApp || -1
      };
      qb_bridge.exec(callback, null, "x5gameplayer", "share", obj );
});browser.define("browser.x5gameplayer.login", function(options, callback){
       var obj = {
         "appid" : options.appid,
         "appsig" : options.appsig,
         "appsigData" : options.appsigData,
         "loginType" : options.loginType
       }
       qb_bridge.exec(callback, null, "x5gameplayer", "login", obj );
});browser.define("browser.x5gameplayer.openQb", function(info,callback){
  try {
  	 if (info.url==null) {
       info.url = location.href;
    }
    info.url = encodeURIComponent(info.url);
  	 window.shareCommon = window.shareCommon || {};
    shareCommon.ua = navigator.userAgent;
    shareCommon.isQb = /mqq/ig.test(shareCommon.ua);
    shareCommon.isQQ = /mobile.*qq/gi.test(shareCommon.ua);
    shareCommon.isWX = /micromessenger/gi.test(shareCommon.ua);
    shareCommon.pageStage = null;
    if (shareCommon.isQQ) {
        shareCommon.pageStage = 'qq';
    } else if (shareCommon.isWX) {
        shareCommon.pageStage = 'wx';
    } else if (shareCommon.isQb) {
        shareCommon.pageStage = 'qb';
    } else {
        shareCommon.pageStage = 'other';
    }
  
  	var openUrl = info.url;
  	if(shareCommon.pageStage != 'qb'){
    	openUrl = 'http://game.html5.qq.com/h5Download.html?goUrl=' + info.url;
  	}
    	 var a = document.createElement("a");
  		  a.href = openUrl;
   		 var click = document.createEvent("Event");
    	 click.initEvent("click", false /*bubbles*/, true /*cancellable*/);
    	 callback && callback(true);
    	 a.dispatchEvent(click);
  	 } catch(e) {
   		 callback && callback(false);
    }
});browser.define("browser.x5gameplayer.getGamePlayerAuthInfo", function(callback){
	window.browser_x5gameplayer_getGamePlayerAuthInfo_callback = callback || function() {};
  	var cb = function(callbackParam){
  	 window.browser_x5gameplayer_getGamePlayerAuthInfo_callback(callbackParam);
    window.browser_x5gameplayer_getGamePlayerAuthInfo_callback = null;
   }
  	window.x5mtt.account().getAuthInfoForGameCenter(cb);
});browser.define("browser.x5gameplayer.version", function(options, callback){
	/*请在这里输入API的实现代码*/
   return qb_bridge.exec(callback, null, "x5gameplayer", "version", options );
});browser.define("browser.x5gameplayer.getGameFriends", function(options, callback){
	/*请在这里输入API的实现代码*/
      var obj = {
          "appid" : options.appid,
          "appsig" : options.appsig,
          "qbopenid" : options.qbopenid,
          "qbopenkey": options.qbopenkey
      };
      qb_bridge.exec(callback, null, "x5gameplayer", "getGameFriends", obj );
});browser.define("browser.x5gameplayer.refreshToken", function(options, callback){
       var obj = {
         "appid" : options.appid,
         "qbopenid" : options.qbopenid,
         "refreshToken" : options.refreshToken
       }
       qb_bridge.exec(callback, null, "x5gameplayer", "refreshToken", obj );
});browser.define("browser.x5gameplayer.preloadResource", function(options, callback){
	/*请在这里输入API的实现代码*/
  qb_bridge.exec(callback, null, "x5gameplayer", "preloadResource", options );
});browser.define("browser.x5gameplayer.openTopicCircle", function(options, callback){
	/*请在这里输入API的实现代码*/
   qb_bridge.exec(callback, null, "x5gameplayer", "openTopicCircle", options );
});
browser.define("browser.x5gameplayer.sendToDesktop", function(options,callback){
      obj = {
       "ext" : options.ext || ''  
      };
      qb_bridge.exec(callback, null, "x5gameplayer", "sendToDesktop", obj );
});browser.define("browser.x5gameplayer.config", function(options){
  	
});browser.define("browser.x5gameplayer.pay", function(options, callback){
	/*请在这里输入API的实现代码*/
  	var obj = {
      "appid" : options.appid,
      "appsig" : options.appsig,
      "qbopenid" : options.qbopenid,
      "qbopenkey": options.qbopenkey,
      "payItem":   options.payItem, 
      "payInfo":  options.payInfo, 
      "reqTime":  options.reqTime,  
      "customMeta": options.customMeta || ''
    };
  	 qb_bridge.exec(callback, null, "x5gameplayer", "pay", obj );
});browser.define("browser.x5gameplayer.getUserInfo", function(options, callback){
	/*请在这里输入API的实现代码*/
   qb_bridge.exec(callback, null, "x5gameplayer", "getUserInfo", options );
});browser.define("browser.x5gameplayer.getAvailableLoginType", function(options, callback){
	/*请在这里输入API的实现代码*/
   return qb_bridge.exec(callback, null, "x5gameplayer", "getAvailableLoginType", options );
});browser.define("browser.x5gameplayer.sendMsg", function(options){
	/*请在这里输入API的实现代码*/
  	qb_bridge.exec(null, null, "x5gameplayer", "sendMsg", options );
});browser.define("browser.x5gameplayer.showAd", function(options, callback){
	/*请在这里输入API的实现代码*/
  	qb_bridge.exec(callback, null, "x5gameplayer", "showAd", options );
});browser.define("browser.x5gameplayer.recharge", function(options, callback){
  	var obj = {
      "appid" : options.appid,
      "paysig" : options.paysig,
      "qbopenid" : options.qbopenid,
      "qbopenkey": options.qbopenkey,
      "reqTime":  options.reqTime,  
      "amount": options.amount || 0
    };
  	 qb_bridge.exec(callback, null, "x5gameplayer", "recharge", obj );
});
browser.define("browser.x5gameplayer.showMoreGame", function(options, callback){
	qb_bridge.exec(callback, null, "x5gameplayer", "showMoreGame", options );
});browser.define("browser.x5gameplayer.getValue", function(options){
	return qb_bridge.exec(null, null, "x5gameplayer", "getValue", options );
});browser.define("browser.tts.setMode", function(args){
  //args:{“iMode":101}
	qb_bridge.exec(null,null,"tts","setMode",args);
});browser.define("browser.tts.start", function(args){
  //args:{'text':'xxxxxx'}
	qb_bridge.exec(null,null,"tts","start",args);
});browser.define("browser.tts.stop", function(/*参数列表*/){
	qb_bridge.exec(null,null,"tts","stop",null);
});browser.define("browser.tts.pauseSpeak", function(/*参数列表*/){
	qb_bridge.exec(null,null,"tts","pauseSpeak",null);
});browser.define("browser.tts.continueSpeak", function(/*参数列表*/){
	qb_bridge.exec(null,null,"tts","continueSpeak",null);
});browser.define("browser.tts.init", function(succCb,failCb){
	qb_bridge.exec(succCb,failCb,"tts","init",null)
});browser.define("browser.tts.destroy", function(/*参数列表*/){
	qb_bridge.exec(null,null,"tts","destroy",null);
});browser.define("browser.skin.getSkinDownloadProgress", function(succCallback, errCallback,options){
	qb_bridge.exec(succCallback,errCallback,"skin","getSkinDownloadProgress",options)
});browser.define("browser.skin.switchToSkin", function(succCallback,errCallback,options){
	qb_bridge.exec(succCallback,errCallback,"skin","switchToSkin",options)
});browser.define("browser.skin.getUsingSkinName", function(succCallback,errCallback){
	qb_bridge.exec(succCallback,errCallback,"skin","getUsingSkinName",null)
});browser.define("browser.skin.getDownloadingSkinList", function(succCallback,errCallback){
	qb_bridge.exec(succCallback,errCallback,"skin","getDownloadingSkinList",null)
});browser.define("browser.skin.getDownloadSkinList", function(succCallback, errCallback){
	qb_bridge.exec(succCallback,errCallback,"skin","getDownloadSkinList",null)
});browser.define("browser.skin.downloadSkin", function(succCallback, errCallback, options){
	qb_bridge.exec(succCallback,errCallback,"skin","downloadSkin",options)
});browser.define("browser.share.favor", function(succCallback, errCallback,options){
	qb_bridge.exec(succCallback, errCallback, "share", "favor", options);
});browser.define("browser.share.delFavor", function(succCallback, errCallback,options){
	qb_bridge.exec(succCallback, errCallback, "share", "delFavor", options);
});browser.define("browser.share.hasFavored", function(succCallback,options){
	return qb_bridge.exec(succCallback,null,"share","hasFavored",options);
});browser.define("browser.usercenter.openInNewPage", function(options){
  	qb_bridge.exec(null, null, "account", "openInNewPage", options);
});browser.define("browser.usercenter.setCurrentWindowTitle", function(options){
  x5.exec(function(){},function(){},"usercenter","setCurrentWindowTitle",[options]);
});browser.define("browser.usercenter.openInBrowserWindow", function(options){
	qb_bridge.exec(null, null, "account", "openInBrowserWindow", options);
});browser.define("browser.usercenter.saveUserAddress", function(options){
	qb_bridge.exec(null, null, "usercenter", "saveUserAddress", options);
});browser.define("browser.usercenter.getRegionInfo", function(succCallback, options){
  	qb_bridge.exec(succCallback, null, "usercenter", "getRegionInfo", options);
});browser.define("browser.usercenter.showUserVerifyView", function(options, callback){
	qb_bridge.exec(callback, null, "usercenter", "showUserVerifyView", options );
});browser.define("browser.usercenter.queryUserVerifyResult", function(options, callback){
	qb_bridge.exec(callback, null, "usercenter", "queryUserVerifyResult", options );
});browser.define("browser.usercenter.onUserVerifyResult", function(options, callback){
	qb_bridge.exec(callback, null, "usercenter", "onUserVerifyResult", options );
});browser.define("browser.weapp.add", function(options, callback){
	qb_bridge.exec(callback, null, "weapp", "add", options);
});browser.define("browser.weapp.getList", function(options, callback){
	qb_bridge.exec(callback, null, 'weapp', 'getList', options);
});browser.define("browser.weapp.remove", function(options, callback){
	qb_bridge.exec(callback, null, "weapp", "remove", options);
});browser.define("browser.audiofm.openUrlInBrowser", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback, "audiofm", "openUrlInBrowser", options);
});browser.define("browser.audiofm.setCommentInfo", function (succCallback, errCallback, options) {
  qb_bridge.exec(succCallback, errCallback, "audiofm", "setCommentInfo", options);
});browser.define("browser.audiofm.audioDownload", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback, "audiofm", "audioDownload", options);
});browser.define("browser.audiofm.optSubscription", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback, "audiofm", "optSubscription", options);
});browser.define("browser.audiofm.showSoftInput", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback, "audiofm", "showSoftInput", options);
});browser.define("browser.audiofm.optCollection", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback, "audiofm", "optCollection", options);
});browser.define("browser.audiofm.audioPlay", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback, "audiofm", "audioPlay", options);
});browser.define("browser.audiofm.audioListPlay", function (succCallback, errCallback, options) {
  qb_bridge.exec(succCallback, errCallback, "audiofm", "audioListPlay", options);
});browser.define("browser.audiofm.setBarTitle", function (succCallback, errCallback, options) {
  qb_bridge.exec(succCallback, errCallback, "audiofm", "setBarTitle", options);
});browser.define("browser.audiofm.audioBatchDownload", function(succCallback, errCallback, options){
  qb_bridge.exec(succCallback, errCallback, "audiofm", "audioBatchDownload", options);
});
